@@ -2,7 +2,7 @@
 
 from qiniu import config, QiniuMacAuth
 from qiniu import http
-from qiniu.utils import urlsafe_base64_encode, entry
+from qiniu.utils import urlsafe_base64_encode, entry, decode_entry
 
 
 class BucketManager(object):
@@ -60,8 +60,8 @@ class BucketManager(object):
             options['delimiter'] = delimiter
 
         ak = self.auth.get_access_key()
-        rs_host = self.zone.get_rsf_host(ak, bucket)
-        url = '{0}/list'.format(rs_host)
+        rsf_host = self.zone.get_rsf_host(ak, bucket)
+        url = '{0}/list'.format(rsf_host)
         ret, info = self.__get(url, options)
 
         eof = False
@@ -243,7 +243,7 @@ class BucketManager(object):
         Args:
             bucket:         待操作资源所在空间
             key:            待操作资源文件名
-            storage_type:   待操作资源存储类型，0为普通存储，1为低频存储，2 为归档存储，3 为深度归档
+            storage_type:   待操作资源存储类型，0为普通存储，1为低频存储，2 为归档存储，3 为深度归档，4 为归档直读存储
         """
         resource = entry(bucket, key)
         return self.__rs_do(bucket, 'chtype', resource, 'type/{0}'.format(storage_type))
@@ -289,7 +289,8 @@ class BucketManager(object):
         to_archive_after_days=0,
         to_deep_archive_after_days=0,
         delete_after_days=0,
-        cond=None
+        cond=None,
+        to_archive_ir_after_days=0
     ):
         """
 
@@ -303,6 +304,7 @@ class BucketManager(object):
             to_deep_archive_after_days: 多少天后将文件转为深度归档存储，设置为 -1 表示取消已设置的转深度归档存储的生命周期规则， 0 表示不修改转深度归档生命周期规则
             delete_after_days: 多少天后将文件删除，设置为 -1 表示取消已设置的删除存储的生命周期规则， 0 表示不修改删除存储的生命周期规则。
             cond: 匹配条件，只有条件匹配才会设置成功，当前支持设置 hash、mime、fsize、putTime。
+            to_archive_ir_after_days: 多少天后将文件转为归档直读存储，设置为 -1 表示取消已设置的转归档只读存储的生命周期规则， 0 表示不修改转归档只读存储生命周期规则。
 
         Returns:
             resBody, respInfo
@@ -310,6 +312,7 @@ class BucketManager(object):
         """
         options = [
             'toIAAfterDays', str(to_line_after_days),
+            'toArchiveIRAfterDays', str(to_archive_ir_after_days),
             'toArchiveAfterDays', str(to_archive_after_days),
             'toDeepArchiveAfterDays', str(to_deep_archive_after_days),
             'deleteAfterDays', str(delete_after_days)
@@ -341,7 +344,20 @@ class BucketManager(object):
                 ]
             一个ResponseInfo对象
         """
-        url = '{0}/batch'.format(config.get_default('default_rs_host'))
+        if not operations:
+            raise Exception('operations is empty')
+        bucket = ''
+        for op in operations:
+            segments = op.split('/')
+            e = segments[1] if len(segments) >= 2 else ''
+            bucket, _ = decode_entry(e)
+            if bucket:
+                break
+        if not bucket:
+            raise Exception('bucket is empty')
+        ak = self.auth.get_access_key()
+        rs_host = self.zone.get_rs_host(ak, bucket)
+        url = '{0}/batch'.format(rs_host)
         return self.__post(url, dict(op=operations))
 
     def buckets(self):
